package cern.ws.demo;

import java.net.URL;

import javax.xml.namespace.QName;
import javax.xml.rpc.ParameterMode;

import org.apache.axis.client.Call;
import org.apache.axis.client.Service;
import org.apache.axis.encoding.XMLType;
import org.apache.axis.utils.Options;

/**
 *  This is a simple client to the Message Service.  On the command line passing '-l<URL>' 
 *  allows you to override the default endpoint URL.
 *  
 *  The Default endpoint is ser to http://localhost:8080/axis/servies/MessageService
 *
 *@author     Derek Mathieson
 *@created    August 15, 2003
 */
public class Client
{
    private String name;
    private String colour;
    private String[] m_args;

    Client(String[] args)
    {
        m_args = args;
    }


    /**
     *  Sets the message attribute of the Client object
     *
     *@param  n              The name to be set
     *@param  c              The background color
     *@exception  Exception  When something goes wrong
     */
    public void setMessage(String n, String c) throws Exception
    {
        String[] args = new String[m_args.length + 2];

        System.arraycopy(m_args, 0, args, 0, m_args.length);

        args[args.length - 2] = n;
        args[args.length - 1] = c;

        setMessage(args);
    }


    /**
     *  Sets the message attribute of the Client object
     *
     *@param  args           The arguments to the setMessage Call
     *@exception  Exception  When something goes wrong
     */
    public void setMessage(String args[]) throws Exception
    {
        Options opts = new Options(args);

        args = opts.getRemainingArgs();

        if (args == null)
        {
            System.err.println("Usage: setMessage <name> <colour>");
            System.exit(1);
        }

        name = args[0];
        colour = args[1];

        URL url = new URL(opts.getURL());
        String user = opts.getUser();
        String passwd = opts.getPassword();

        Service service = new Service();

        Call call = (Call)service.createCall();

        call.setTargetEndpointAddress(url);
        call.setOperationName(new QName("MessageService", "setMessage"));
        call.addParameter("name", XMLType.XSD_STRING, ParameterMode.IN);
        call.addParameter("colour", XMLType.XSD_STRING, ParameterMode.IN);
        call.setReturnType(XMLType.XSD_STRING);

        call.setUsername(user);
        call.setPassword(passwd);

        Object ret = call.invoke(new Object[]{name, colour});
        System.out.println(ret.toString());
    }


    /**
     *  The main program for the Client class
     *
     *@param  args  The command line arguments
     */
    public static void main(String[] args)
    {
        Client client = new Client(args);
        ClientFrame frame = new ClientFrame(client);

        frame.create();
    }

}
