package cern.ws.demo;

import java.awt.*;
import java.awt.event.*;

import javax.swing.*;

/**
 *  User interface for simple MessageService Client 
 *
 *@author     Derek Mathieson
 *@created    August 15, 2003
 */
public class ClientFrame extends JFrame
{
    private JLabel jLabel1 = new JLabel();
    private JTextField nameField = new JTextField();
    private JLabel jLabel2 = new JLabel();
    private GridBagLayout gridBagLayout1 = new GridBagLayout();
    private ListSelectionModel listSelectionModel1 = new DefaultListSelectionModel();
    private JComboBox colourChoice = new JComboBox();
    private ComboBoxModel comboBoxModel1 = new DefaultComboBoxModel();
    private JButton jButton1 = new JButton();
    private JPanel jPanel1 = new JPanel();
    private Client m_client;


    /**
     *  Constructor for the ClientFrame object
     *
     *@param  clnt  reference to Client that this is the GUI for.
     */
    public ClientFrame(Client clnt)
    {
        DefaultComboBoxModel colours = new DefaultComboBoxModel();

        m_client = clnt;

        colours.addElement("Red");
        colours.addElement("Yellow");
        colours.addElement("Green");
        colours.addElement("Blue");
        colours.addElement("White");
        colours.addElement("Pink");
        colours.addElement("Orange");
        colours.addElement("Cyan");
        colours.addElement("LightGray");
        comboBoxModel1 = (ComboBoxModel)colours;

        try
        {
            jbInit();
        }
        catch (Exception e)
        {
            e.printStackTrace();
        }
    }


    private void jbInit() throws Exception
    {
        this.setTitle("Web Service Client");
        this.getContentPane().setLayout(gridBagLayout1);
        this.setSize(new Dimension(500, 280));
        jLabel1.setText("Name:");
        jLabel1.setFont(new Font("Dialog", 0, 32));
        nameField.setText("Derek");
        nameField.setFont(new Font("SansSerif", 0, 32));
        jLabel2.setText("Colour:");
        jLabel2.setFont(new Font("Dialog", 0, 32));
        colourChoice.setModel(comboBoxModel1);
        colourChoice.setSelectedItem(this);
        colourChoice.setFont(new Font("SansSerif", 0, 32));
        jButton1.setText("Set Message");
        jButton1.setFont(new Font("Dialog", 0, 32));
        jButton1.addActionListener(
            new ActionListener()
            {
                public void actionPerformed(ActionEvent e)
                {
                    jButton1_actionPerformed(e);
                }
            });
        this.getContentPane().add(jLabel2, new GridBagConstraints(0, 3, 1, 1, 0.0, 0.0, GridBagConstraints.WEST, GridBagConstraints.NONE, new Insets(0, 4, 4, 0), 0, 0));
        this.getContentPane().add(jLabel1, new GridBagConstraints(0, 2, 1, 1, 0.0, 0.0, GridBagConstraints.WEST, GridBagConstraints.NONE, new Insets(0, 4, 4, 0), 0, 0));
        this.getContentPane().add(nameField, new GridBagConstraints(1, 2, 1, 1, 1.0, 0.0, GridBagConstraints.WEST, GridBagConstraints.HORIZONTAL, new Insets(0, 4, 4, 4), 0, 0));
        this.getContentPane().add(colourChoice, new GridBagConstraints(1, 3, 1, 1, 0.0, 0.0, GridBagConstraints.CENTER, GridBagConstraints.HORIZONTAL, new Insets(0, 4, 0, 4), 0, 0));
        this.getContentPane().add(jButton1, new GridBagConstraints(0, 4, 2, 1, 1.0, 1.0, GridBagConstraints.SOUTH, GridBagConstraints.NONE, new Insets(0, 0, 8, 8), 0, 0));
        this.getContentPane().add(jPanel1, new GridBagConstraints(1, 1, 1, 1, 0.0, 1.0, GridBagConstraints.CENTER, GridBagConstraints.NONE, new Insets(0, 0, 0, 0), 0, 0));
    }


    private void jButton1_actionPerformed(ActionEvent e)
    {
        try
        {
            m_client.setMessage(nameField.getText(), colourChoice.getSelectedItem().toString());
        }
        catch (Exception ex)
        {
            ex.printStackTrace();
        }
    }


    /**
     *  Causes the Frame to appear centred on the display.
     */
    public void create()
    {
        Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
        Dimension frameSize = getPreferredSize();

        if (frameSize.height > screenSize.height)
        {
            frameSize.height = screenSize.height;
        }
        if (frameSize.width > screenSize.width)
        {
            frameSize.width = screenSize.width;
        }
        setLocation((screenSize.width - frameSize.width) / 2, (screenSize.height - frameSize.height) / 2);

        addWindowListener(
            new WindowAdapter()
            {
                public void windowClosing(WindowEvent e)
                {
                    System.exit(0);
                }
            });

        setVisible(true);
    }

}
