package cern.ws.demo;

import java.awt.Graphics;
import java.awt.Image;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;

import javax.swing.ImageIcon;
import javax.swing.JPanel;
import java.awt.image.*;
import java.awt.Dimension;

/**
 *  Simple Panel which displays an Image - scales to fill panel
 *
 *@author     dmathies
 *@created    August 15, 2003
 */
public class ImagePanel extends JPanel
{
    ImageIcon m_icon = new ImageIcon();
    Image m_img = null;

    /**
     *  Constructor for the ImagePanel object
     */
    public ImagePanel() { }

    /**
     *  Sets the icon attribute of the ImagePanel object
     *
     *@param  i  The new icon value
     */
    public void setIcon(ImageIcon i)
    {
        m_icon = i;
        setImage();
    }

    /**
     *  Sets the image attribute of the ImagePanel object
     *
     *@param  image  The new image value
     */
    public void setImage(Image image)
    {
        m_icon.setImage(image);
        setImage();
    }


    /**
     *  Gets the image attribute of the ImagePanel object
     *
     *@return    The image value
     */
    public Image getImage()
    {
        return m_icon.getImage();
    }

    private void setImage()
    {
      if (getWidth()>0 && getHeight()>0)
        m_img = m_icon.getImage().getScaledInstance(getWidth(), getHeight(), Image.SCALE_FAST);
    }
    
    public void update(Graphics g)
    {
        g.drawImage(m_img, 0, 0, getWidth(), getHeight(), this);
    }

    public void paint(Graphics g)
    {
        update(g);
    }

    public boolean imageUpdate(Image img, int infoflags, int x, int y, int width, int height)
    {
      if (img == m_img)
      {
        if ((infoflags & (ImageObserver.ERROR | ImageObserver.ABORT))>0)
          return false;

        if ((infoflags & ImageObserver.ALLBITS) >0)
        {
          repaint();

          return false;
        }

        return true;
      }

      return false;
    }

  public void setSize(Dimension d)
  {
    super.setSize(d);
    setImage();
  }

  public void setSize(int width, int height)
  {
    super.setSize(width, height);
    setImage();
  }

  public void reshape(int x, int y, int w, int h)
  {
    super.reshape(x, y, w, h);
    setImage();
  }
}
