package cern.ws.demo;

import cern.ws.demo.MessageMonitorFrame;

import java.awt.Dimension;
import java.awt.Toolkit;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

import javax.swing.*;
import javax.swing.UIManager;

import org.apache.axis.transport.http.*;

/**
 *  Controller class for Web Service UI
 *
 *@author     Derek Mathieson
 *@created    August 15, 2003
 */
public class ServiceDisplay
{
    static MessageMonitorFrame frame;

    /**
     *  Constructor for the ServiceDisplay object
     */
    public ServiceDisplay()
    {
        frame = new MessageMonitorFrame();
        Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
        frame.setSize(screenSize);

        frame.setLocation(0, 0);
        frame.addWindowListener(
            new WindowAdapter()
            {
                public void windowClosing(WindowEvent e)
                {
                    System.exit(0);
                }
            });
        frame.setVisible(true);
    }


    /**
     *  Sets the message attribute of the ServiceDisplay class
     *
     *@param  name    The name of the person to greet
     *@param  colour  The new background colour
     */
    public static void setMessage(String name, String colour)
    {
        if (frame == null)
        {
            new ServiceDisplay();
        }

        if (frame != null)
        {
            SwingUtilities.invokeLater(new RunLater(frame, name, colour));
        }
    }


    /**
     *  The main program for the ServiceDisplay class
     *
     *@param  args  The command line arguments
     */
    public static void main(String[] args)
    {
        try
        {
            UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
        }
        catch (Exception e)
        {
            e.printStackTrace();
        }

        new ServiceDisplay();
        SimpleAxisServer.main(new String[]{"-p", "8080"});
    }

}

class RunLater implements Runnable
{
    MessageMonitorFrame m_f;
    String m_name;
    String m_colour;

    RunLater(MessageMonitorFrame f, String name, String colour)
    {
        m_f = f;
        m_name = name;
        m_colour = colour;
    }

    /**
     *  Main processing method for the RunLater object
     */
    public void run()
    {
        m_f.setMessage(m_name, m_colour);
    }
}
